@@ -135,7 +135,12 @@ class Query:
         return self
 
     def get_path_of_query(self):
-        return "/".join(self.firebase_query._parent._path)
+        if getattr(self.firebase_query, "_path", None):
+            return "/".join(self.firebase_query._path)
+        if getattr(self.firebase_query, "_parent", None):
+            return "/".join(self.firebase_query._parent._path)
+        else:
+            return self.collection_path
 
     """Querying and creating of the models."""
 
